aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorChris Gianelloni <wolf31o2@gentoo.org>2005-04-05 21:43:09 +0000
committerChris Gianelloni <wolf31o2@gentoo.org>2005-04-05 21:43:09 +0000
commit68f3d282aad6e30c818b1f574cb067626ba13887 (patch)
treeb3ff7eb4677e21197dbb6ea74f53366ec7db3b45
parentRemoved a few comments from the livecd-stage2-controller.sh file (diff)
downloadcatalyst-68f3d282aad6e30c818b1f574cb067626ba13887.tar.gz
catalyst-68f3d282aad6e30c818b1f574cb067626ba13887.tar.bz2
catalyst-68f3d282aad6e30c818b1f574cb067626ba13887.zip
Changed maintainers. Updated examples/fsscript.sh.example to provide better documentation. Lots of minor cosmetic updates. Updated minimal.motd.txt and universal.motd.txt to resolve documentation issue on bug #86914. Added x-setup to default runlevel on gamecd builds. Removed extranneous bashlogin sed-fu from livecdfs-update.sh and made default timezone UTC rather than GMT.
git-svn-id: svn+ssh://svn.gentoo.org/var/svnroot/catalyst/trunk@580 d1e1f19c-881f-0410-ab34-b69fee027534
-rw-r--r--ChangeLog14
-rwxr-xr-xcatalyst9
-rw-r--r--examples/fsscript.sh.example6
-rw-r--r--livecd/files/README.txt2
-rw-r--r--livecd/files/livecd-bash_profile2
-rw-r--r--livecd/files/livecd-bashrc5
-rw-r--r--livecd/files/minimal.motd.txt6
-rw-r--r--livecd/files/universal.motd.txt2
-rwxr-xr-xtargets/support/gamecdfs-update.sh1
-rwxr-xr-xtargets/support/livecdfs-update.sh9
10 files changed, 36 insertions, 20 deletions
diff --git a/ChangeLog b/ChangeLog
index 897fb773..f8cd7533 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,6 +1,18 @@
# ChangeLog for gentoo/src/catalyst
# Copyright 2002-2005 Gentoo Foundation; Distributed under the GPL v2
-# $Header: /var/cvsroot/gentoo/src/catalyst/ChangeLog,v 1.202 2005/04/05 21:42:20 rocket Exp $
+# $Header: /var/cvsroot/gentoo/src/catalyst/ChangeLog,v 1.203 2005/04/05 21:43:09 wolf31o2 Exp $
+
+ 05 Apr 2005; Chris Gianelloni <wolf31o2@gentoo.org> catalyst,
+ examples/fsscript.sh.example, livecd/files/README.txt,
+ livecd/files/livecd-bash_profile, livecd/files/livecd-bashrc,
+ livecd/files/minimal.motd.txt, livecd/files/universal.motd.txt,
+ targets/support/gamecdfs-update.sh, targets/support/livecdfs-update.sh:
+ Changed maintainers. Updated examples/fsscript.sh.example to provide better
+ documentation. Lots of minor cosmetic updates. Updated minimal.motd.txt and
+ universal.motd.txt to resolve documentation issue on bug #86914. Added
+ x-setup to default runlevel on gamecd builds. Removed extranneous bashlogin
+ sed-fu from livecdfs-update.sh and made default timezone UTC rather than
+ GMT.
05 Apr 2005; Eric Edgar <rocket@gentoo.org>
targets/livecd-stage2/livecd-stage2-controller.sh:
diff --git a/catalyst b/catalyst
index ea5609db..f4f39d54 100755
--- a/catalyst
+++ b/catalyst
@@ -1,14 +1,17 @@
#!/usr/bin/python
# Copyright 1999-2004 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo/src/catalyst/catalyst,v 1.69 2005/04/04 17:48:32 rocket Exp $
+# $Header: /var/cvsroot/gentoo/src/catalyst/catalyst,v 1.70 2005/04/05 21:43:09 wolf31o2 Exp $
-# Maintained in full by John Davis <zhen@gentoo.org>
+# Maintained in full by:
+# Eric Edgar <rocket@gentoo.org>
+# Chris Gianelloni <rwolf31o2@gentoo.org>
+# John Davis <zhen@gentoo.org>
import os,sys,imp,string,getopt
__maintainer__="Chris Gianelloni <wolf31o2@gentoo.org>"
-__version__="2.0.0"
+__version__="2.0.0_pre1"
conf_values={}
diff --git a/examples/fsscript.sh.example b/examples/fsscript.sh.example
index 1d40cf4b..47dd5a67 100644
--- a/examples/fsscript.sh.example
+++ b/examples/fsscript.sh.example
@@ -1,7 +1,9 @@
#!/bin/bash
-# This is an example fsscript for use with the livecd-stage2 target (key livecd/fsscript)
-# Basically, this file is copied to the livecd rootfs at livecd creation time and then run
+# This is an example fsscript for use with the livecd-stage2 target via the
+# spec file option livecd/fsscript. Basically, this file is copied to the
+# livecd rootfs at livecd creation time and then executed from within the
+# chroot.
# Example, I want to add specific nameservers to the LiveCD's resolv.conf:
echo "192.168.0.1" >> /etc/resolv.conf
diff --git a/livecd/files/README.txt b/livecd/files/README.txt
index d8e385fa..1f2682a6 100644
--- a/livecd/files/README.txt
+++ b/livecd/files/README.txt
@@ -12,7 +12,7 @@ Mailing Lists: Please see our quick Mailing List HOWTO at:
Gentoo user forums: <http://forums.gentoo.org>
-Gentoo Bug Database <http://bugs.gentoo.org>
+Gentoo Bug Database: <http://bugs.gentoo.org>
On this LiveCD, we've provided a minimal IRC client called "irssi" and a simple
text web browser called "links." Both can be accessed via the command line by
diff --git a/livecd/files/livecd-bash_profile b/livecd/files/livecd-bash_profile
index 9ec49d6b..4fc919bf 100644
--- a/livecd/files/livecd-bash_profile
+++ b/livecd/files/livecd-bash_profile
@@ -1,4 +1,4 @@
#!/bin/bash
#This file is sourced by bash when you log in interactively.
-[ -f ~/.bashrc ] && . ~/.bashrc
+[[ -f ~/.bashrc ]] && . ~/.bashrc
diff --git a/livecd/files/livecd-bashrc b/livecd/files/livecd-bashrc
index c904ed8d..8e9ba6b2 100644
--- a/livecd/files/livecd-bashrc
+++ b/livecd/files/livecd-bashrc
@@ -1,9 +1,10 @@
#!/bin/bash
-if [ -e /usr/X11R6/bin/X ]; then
+if [ -e /usr/bin/X ]; then
if [ -e /etc/startx ]; then
rm -f /etc/startx
- startx
+ export BASHRC_READ=1
+ #startx
cat /etc/motd
fi
fi
diff --git a/livecd/files/minimal.motd.txt b/livecd/files/minimal.motd.txt
index 5b3f909d..7682082e 100644
--- a/livecd/files/minimal.motd.txt
+++ b/livecd/files/minimal.motd.txt
@@ -1,12 +1,10 @@
+The latest version of the Handbook is always available from the Gentoo web site
+by typing "links http://www.gentoo.org/doc/en/handbook/handbook.xml".
To start an ssh server on this system, type "/etc/init.d/sshd start". If you
need to log in remotely as root, type "passwd root" to reset root's password
to a known value.
-View installation instructions by typing "links /mnt/cdrom/docs/handbook/html/index.html"
-or "links http://www.gentoo.org/doc/en/handbook/handbook.xml"
-for the latest version from the gentoo.org web site.
-
Please report any bugs you find to http://bugs.gentoo.org. Be sure to include
detailed information about how to reproduce the bug you are reporting.
Thank you for using Gentoo Linux!
diff --git a/livecd/files/universal.motd.txt b/livecd/files/universal.motd.txt
index 51b2fde8..403b8729 100644
--- a/livecd/files/universal.motd.txt
+++ b/livecd/files/universal.motd.txt
@@ -1,3 +1,5 @@
Stage tarball(s), distfiles and packages can be found in /mnt/cdrom/.
+You can view the networkless installation instructions for this release by
+typing "links /mnt/cdrom/docs/handbook/html".
diff --git a/targets/support/gamecdfs-update.sh b/targets/support/gamecdfs-update.sh
index b456f86d..69281201 100755
--- a/targets/support/gamecdfs-update.sh
+++ b/targets/support/gamecdfs-update.sh
@@ -14,3 +14,4 @@ echo "exec ${GAME_EXECUTABLE}" > /etc/X11/xinit/xinitrc
# we add spind to default here since we don't want the CD to spin down
rc-update add spind default
+rc-update add x-setup default
diff --git a/targets/support/livecdfs-update.sh b/targets/support/livecdfs-update.sh
index f6621e86..16cebe00 100755
--- a/targets/support/livecdfs-update.sh
+++ b/targets/support/livecdfs-update.sh
@@ -1,7 +1,7 @@
#!/bin/bash
# Copyright 1999-2004 Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
-# $Header: /var/cvsroot/gentoo/src/catalyst/targets/support/livecdfs-update.sh,v 1.1 2005/04/04 17:48:33 rocket Exp $
+# $Header: /var/cvsroot/gentoo/src/catalyst/targets/support/livecdfs-update.sh,v 1.2 2005/04/05 21:43:09 wolf31o2 Exp $
/usr/sbin/env-update
source /etc/profile
@@ -15,9 +15,6 @@ fi
# turn off udev tarball
sed -i 's:RC_DEVICE_TARBALL="yes":RC_DEVICE_TARBALL="no":' /etc/conf.d/rc
-# turn bashlogin shells to actual login shells
-sed -i 's:exec -l /bin/bash:exec -l /bin/bash -l:' /bin/bashlogin
-
# default programs that we always want to start
rc-update del iptables default
rc-update del netmount default
@@ -64,9 +61,9 @@ then
fi
fi
# clean up the time and set to GMT
rm -rf /etc/localtime
-cp /usr/share/zoneinfo/GMT /etc/localtime
+cp /usr/share/zoneinfo/UTC /etc/localtime
# setup the hostname
echo "livecd" > /etc/hostname
@@ -64,9 +61,9 @@ then
fi
fi
-# clean up the time and set to GMT
+# clean up the time and set to UTC
rm -rf /etc/localtime